/**
 * Parse an expression.
 * @function parseExpression
 * @param {string} expression - Expression to parse.
 * @param {object} scope - Scope data.
 * @param {object} [options] - Optional settings.
 * @param {object} [options.pattern=/#{(.*?)}/g] - Expression pattern..
 */

'use strict';

var expressionError = require('../errors/expression_error');

/** @lends parseExpression */
function parseExpression(expression, context) {
  var options = arguments.length <= 2 || arguments[2] === undefined ? {} : arguments[2];

  var pattern = options.pattern || /[#\$]{(.*?)}/g;
  return String(expression).replace(pattern, function ($0, $1) {
    try {
      return function () {
        var declares = 'let s = this,' + Object.keys(context || {}).map(function (key) {
          return key + '=s.' + key;
        }).join(', ');
        // noinspection Eslint
        return eval('"use strict";' + declares + ';' + $1);
      }.call(context);
    } catch (e) {
      throw expressionError(expression, e);
    }
  });
}

module.exports = parseExpression;
//# sourceMappingURL=data:application/json;base64,bnVsbA==